<?php
/**
 * Functions for fashionclaire theme
 * @package fashionclaire
 * @since fashionclaire 1.1.1
 * 
 */

if ( !function_exists ('fashionclaire_setup') ) : 
    function fashionclaire_setup(){
        if ( ! defined('FASHIONCLAIRE')){
            define ('FASHIONCLAIRE', 'fashionclaire');
        }

        load_theme_textdomain('fashionclaire', get_template_directory() . '/languages');

        // Excsusive Theme Support
        add_theme_support('title-tag');
        add_theme_support('automatic-feed-links');
        add_theme_support('post-thumbnails');
        add_theme_support(
            'html5', 
            array(
                'comment-form',
                'search-form',
                'comments-list',
                'gallery',
                'caption',
            ) 
        );
    
        add_theme_support ( 'custom-logo', array (
            'height'        =>  90,
            'width'         =>  220,
            'flex-height'   =>  false,
            'flex-width'    =>  false,
        ));
    
        add_theme_support( 'custom-background', apply_filters( 'fashionclaire_custom_background_args', array(
            'default-color' =>  'ffffff',
            'default-image' =>  '',
        )));

        add_theme_support( 'title-tag' );
    
        add_theme_support(
            'post-formats',
                array(
                    'audio',
                    'video',
                    'gallery',
                    'quote',
                    'link',
                    'aside',
                    'image',
                )
        );

        //Add sypport Block Styles
        add_theme_support ('wp-block-styles');

        //Add support editor styles
        add_theme_support('editor-styles');

        // Enqueue editor styles
        add_editor_style('style-editor.css');

        add_theme_support (
            'editor-color-palette', array(
            array(
                'name'  =>  esc_html__('White', 'fashionclaire' ),
                'slug'  =>  'white',
                'color' =>  '#ffffff', 
            ),

            array(
                'name'  =>  esc_html__('Light Grey', 'fashionclaire' ),
                'slug'  =>  'grey-200',
                'color' =>  '#e6e6e6', 
            ),

            array(
                'name'  =>  esc_html__('Medium Grey', 'fashionclaire' ),
                'slug'  =>  'grey-500',
                'color' =>  '#919191', 
            ),

            array(
                'name'  =>  esc_html__('Primary', 'fashionclaire' ),
                'slug'  =>  'primary',
                'color' =>  apply_filters('fashionclaire_primary_color', '#151515'), 
            ),

            array(
                'name'  =>  esc_html__('Gold', 'fashionclaire' ),
                'slug'  =>  'gold',
                'color' =>  '#aa8c00', 
            ),

        ));
    
        // Enable support for Post Thubnails on Posts and Pages
        add_image_size('fashionclaire-xsmall', 300, 230, true);
        add_image_size('fashionclaire-large', 9999, 520, false);
        add_image_size('fashionclaire-full', 1200, 560, true);
            
        // Navigation Menu.
        register_nav_menus (array(
            'primary' => esc_html__( 'Primary Menu', 'fashionclaire')
        ));
    }
    endif; //End of fashionclaire_setup
    add_action ('after_setup_theme', 'fashionclaire_setup');

    function fashionclaire_fonts_url() {
        $fonts_url = '';
            
        $pt_serif = _x( 'on', 'PT Serif font: on or off', 'fashionclaire' );
            
        if ( 'off' !== $pt_serif ) {
        $font_families[] = 'Anton|Abril+Fatface|Advent+Pro:400,700|Archivo:400,700|Arimo:400,400italic,700|Arvo:400,400italic,700|Bitter:400,400italic,700|Cardo:400,400italic,700|Chivo:400,400italic,700|Crimson+Text:400,400italic,700|Cormorant:400,400italic,700|Dosis:400,700|Didact+Gothic|EB+Garamond:400,400italic,700,700italic|Fira+Sans:400,400italic,700|Josefin+Sans:400,400italic,700|Judson:400,400italic,700|Krub:400,400italic,700|Lato:400,400italic,700|Lora:400,400italic,700|Merriweather:400,400italic,700|Montserrat:400,400italic,700|Muli:400,400italic,700|Nixie+One|Noto+Sans:400,400italic,700|Questrial|Quicksand:400,700|Old+Standard+TT:400,400italic,700|Open+Sans:400,400italic,700|Oswald:400,700|Oxygen:400,700|Playfair+Display:400,400italic,700|Poppins:400,400italic,700|Prata|PT+Sans:400,400italic,700|PT+Serif:400,400italic,700|PT+Sans+Narrow:400,700|Roboto:400,400italic,700|Roboto+Condensed:400,400italic,700|Roboto+Slab:400,700|Rokkitt:400,700|Rozha+One|Slabo+27px|Source+Sans+Pro:400,400italic,700|Source+Sans+Pro:400,400italic,700|Spectral:400,400italic,700|Suranna|Teko:400,700|Tinos:400,400italic,700|Ubuntu:400,400italic,700|Vidaloka|Work+Sans:400,700|Vollkorn:400,400italic,700|Zilla+Slab:400,400italic,700';
            
        $query_args = array(
        'family' => urlencode( implode( '|', $font_families ) ),
        'subset' => urlencode( 'latin,latin-ext' ),
        );
             
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
        }     
        return esc_url_raw( $fonts_url );
        }

    function fashionclaire_scripts() {
        /**
            * Enqueue scripts and styles.
        */

        wp_enqueue_style( 'fashionclaire-style', get_stylesheet_uri() );

        wp_enqueue_style ('style', get_template_directory_uri() . '/style.css');
        wp_enqueue_style ('style-editor', get_template_directory_uri() . '/style-editor.css');
        wp_enqueue_style ('font-awesome', get_template_directory_uri() . '/fonts/font-awesome.css', array(), '4.7.0');
        wp_enqueue_style ('magnific-popup', get_template_directory_uri() . '/css/magnific-popup.css');
        
        wp_enqueue_script( 'jquery.magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array('jquery'), true );
        wp_enqueue_script( 'jquery.fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array('jquery'), true);
        wp_enqueue_script( 'scripts', get_template_directory_uri() . '/js/scripts.js', array('jquery'), '1.0.2', true );
            
        if (is_singular() && comments_open() && get_option( 'thread_comments' ) ){
        wp_enqueue_script('comment-reply');
        }
    }
    add_action('wp_enqueue_scripts', 'fashionclaire_scripts');

    // Include Template Functions.
    require get_template_directory() . '/inc/widgets.php';
    require get_template_directory() . '/inc/template-functions.php';
    require get_template_directory() . '/inc/template-tags.php';
    require get_template_directory() . '/inc/custom-functions.php';
    require get_template_directory() . '/inc/breadcrumbs.php';

    // Customizer
    require get_template_directory() . '/inc/customizer/customizer.php';
    require get_template_directory() . '/inc/customizer/color-theme-styles.php';
    require get_template_directory() . '/inc/customizer/dynamic-css.php';
    require get_template_directory() . '/inc/customizer/gfonts.php';

    // Widgets
    function fashionclaire_register_widgets(){
        require get_template_directory() . '/inc/widgets/widget-popular-posts.php';
        require get_template_directory() . '/inc/widgets/widget-featured-posts.php';
        require get_template_directory() . '/inc/widgets/widget-social-networks.php';
    }
    add_action ('widgets_init', 'fashionclaire_register_widgets');

    add_action ('after_setup_theme', 'fashionclaire_content_width',0);
    function fashionclaire_content_width(){
        $GLOBALS['content_width'] = apply_filters('fashionclaire_content_width', 770);
    }